@@ -32,7 +32,7 @@ def _run(aux: tuple, data: dict, left: int,
          start_est=True, compute_pdf=False, k_left_bound=1,
          adjusted_loglik=False, adjust_line=False, regul_alpha=0.0, 
          regul_n=True, regul_slice=True, regul_prior='laplace', std=False, 
-         fix_params=str(),optimizer='SLSQP', use_cpu=False):
+         fix_params=str(), optimizer='SLSQP', r_transform=None, use_cpu=False):
     if use_cpu:
         os.environ["JAX_PLATFORM_NAME"] = 'cpu'
         os.environ["XLA_PYTHON_CLIENT_ALLOCATOR"] = 'cpu'
@@ -49,7 +49,8 @@ def _run(aux: tuple, data: dict, left: int,
                    'adjust_line': adjust_line, 'start_est': start_est,
                    'apply_weights': apply_weights, 'regul_alpha': regul_alpha,
                    'regul_n': regul_n, 'regul_slice': regul_slice,
-                   'regul_prior': regul_prior, 'fix_params': fix_params}
+                   'regul_prior': regul_prior, 'fix_params': fix_params,
+                   'r_transform': r_transform}
     model = get_model_creator(**inst_params)()
     fit = model.fit(data, calc_std=std, optimizer=optimizer)
     _finalize_fit(model, fit)
@@ -90,7 +91,8 @@ def fit(name: str, model='line', dist='BetaNB', left=None,
         window_behavior='both', min_slices=1, adjust_line=False, k_left_bound=1,
         max_count=np.inf, max_cover=np.inf, apply_weights=False,  start_est=True,
         adjusted_loglik=False, regul_alpha=0.0, regul_n=True, regul_slice=True, 
-        regul_prior='laplace', std=False, fix_params=str(), optimizer='SLSQP', n_jobs=1):
+        regul_prior='laplace', std=False, fix_params=str(), optimizer='SLSQP', 
+        r_transform=None, n_jobs=1):
     """
 
     Parameters
@@ -178,6 +180,7 @@ def fit(name: str, model='line', dist='BetaNB', left=None,
                   std=std,
                   fix_params=fix_params,
                   optimizer=optimizer,
+                  r_transform=r_transform,
                   use_cpu=(n_jobs != 1))
     result = defaultdict(lambda: defaultdict())
     ralt = {True: 'alt', False: 'ref'}
